/// ABBYY® Mobile Capture © 2019 ABBYY Production LLC.
/// ABBYY is a registered trademark or a trademark of ABBYY Software Ltd.

#import "AUICaptureScenario.h"

NS_ASSUME_NONNULL_BEGIN

@class RTREngine;

/// Document size for capture suggest.
typedef CGSize AUIDocumentSize NS_TYPED_EXTENSIBLE_ENUM;

/// Any document size.
extern AUIDocumentSize const AUIDocumentSizeAny;

/// A4 210 x 297 mm.
extern AUIDocumentSize const AUIDocumentSizeA4;

/// BusinessCard 53.98 x 85.6 mm.
extern AUIDocumentSize const AUIDocumentSizeBusinessCard;

/// Letter 215.9 x 279.4 mm.
extern AUIDocumentSize const AUIDocumentSizeLetter;

@interface AUIImageCaptureResult : NSObject

/// Captured image.
@property (nonatomic, strong) UIImage* image;

/// Boundary for document. NSValue contains CGPoint.
/// You can modify boundary by manual tunning.
@property (nonatomic, strong, nullable) NSArray<NSValue*>* documentBoundary;

@end

@protocol AUIImageCaptureScenarioDelegate;

@class AUIImageCaptureScenario;

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

@protocol AUIImageCaptureScenarioDelegate <AUICaptureScenarioDelegate>

- (void)captureScenario:(AUICaptureScenario*)scenario didFailWithError:(NSError*)error;

- (void)captureScenario:(AUIImageCaptureScenario*)captureScenario didCaptureImageWithResult:(AUIImageCaptureResult*)result;

@end

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

@interface AUIImageCaptureScenario : AUICaptureScenario

@property (nonatomic, weak, nullable) id<AUIImageCaptureScenarioDelegate> delegate;

/// If NO automatic image capturing is disabled. Default YES. After each capture is set to NO.
@property (nonatomic, assign) BOOL active;

/// Minimum document area relative to frame area - 0...1. Default 0.15.
@property (nonatomic, assign) CGFloat minimumDocumentToViewRatio;

/// Document size in millimeters.
@property (nonatomic, assign) AUIDocumentSize documentSize;

/// If YES result image will be cropped and quadrangle result will be nil. Default NO.
@property (nonatomic, assign) BOOL cropEnabled;

- (instancetype)initWithEngine:(RTREngine*)engine;

/// Capture image immediately.
- (void)captureImageManually;

@end

NS_ASSUME_NONNULL_END
