// ABBYY® Mobile Capture © 2019 ABBYY Production LLC.
// ABBYY is a registered trademark or a trademark of ABBYY Software Ltd.

import AbbyyUI

@IBDesignable
class ThumbnailView: UIView {
	var badgeNumber: Int = 0 {
		didSet {
			badgeLabel.text = "\(badgeNumber)"
		}
	}
	var onTap: (() -> ())?

	@IBOutlet weak var imageView: UIImageView!
	@IBOutlet weak var badgeLabel: UILabel!

	var contentView: UIView?

	required init?(coder aDecoder: NSCoder)
	{
		super.init(coder: aDecoder)
		guard let view = loadViewFromNib() else { return }
		view.frame = bounds
		addSubview(view)
		contentView = view
		commonInit()
	}

	func loadViewFromNib() -> UIView?
	{
		let bundle = Bundle(for: type(of: self))
		let nib = UINib(nibName: "\(ThumbnailView.self)", bundle: bundle)
		return nib.instantiate(withOwner: self, options: nil).first as? UIView
	}

	func commonInit()
	{
		let gesture = UITapGestureRecognizer(
			target: self,
			action: #selector(onTapInternal))
		addGestureRecognizer(gesture)
	}

	@objc func onTapInternal()
	{
		onTap?()
	}

	override func aui_canRotate() -> Bool
	{
		return true
	}
}

class CustomCaptureViewController: AUICaptureController {

	var onThumbnailViewTapped: (() -> ())?

	@IBOutlet weak var thumbnailView: ThumbnailView!
	var imageMiniature: UIImage? {
		didSet {
			thumbnailView.imageView.image = imageMiniature
		}
	}

	var framesCaptured: Int = 0 {
		didSet {
			DispatchQueue.main.async { [weak self] in
				if let self = self {
					self.thumbnailView.badgeNumber = self.framesCaptured
					self.thumbnailView.isHidden = self.framesCaptured == 0
				}
			}
		}
	}

	override func viewDidLoad()
	{
		super.viewDidLoad()
		thumbnailView.onTap = onThumbnailViewTapped
		thumbnailView.isHidden = true
	}
}
