// ABBYY® Mobile Capture © 2019 ABBYY Production LLC.
// ABBYY is a registered trademark or a trademark of ABBYY Software Ltd.

#import "PreviewViewController.h"

@interface PreviewViewController ()

@property (nonatomic, weak) IBOutlet UIImageView* imageView;
@property (nonatomic, weak) IBOutlet UILabel* pagesLabel;

@end

@implementation PreviewViewController

- (void)viewDidLoad
{
	[super viewDidLoad];

	self.imageView.image = self.image;
	[self updatePagesLabel];
}

- (void)viewWillAppear:(BOOL)animated
{
	[super viewWillAppear:animated];

	[self setupNavigationBar];
}

- (void)setImage:(UIImage*)image
{
	_image = image;
	self.imageView.image = image;
}

- (void)setImageIndex:(NSInteger)imageIndex
{
	_imageIndex = imageIndex;
	[self updatePagesLabel];
}

- (void)setImagesCount:(NSInteger)imagesCount
{
	_imagesCount = imagesCount;
	[self updatePagesLabel];
}

- (void)setupNavigationBar
{
	self.navigationController.navigationBar.barStyle = UIBarStyleBlack;
	UIBarButtonItem* cancelButton = [[UIBarButtonItem alloc] initWithTitle:NSLocalizedString(@"Delete", nil) style:UIBarButtonItemStylePlain target:self action:@selector(didPressCancel:)];
	cancelButton.tintColor = [UIColor whiteColor];
	self.navigationItem.title = NSLocalizedString(@"SinglePagePreviewTitle", nil);
	self.navigationItem.leftBarButtonItem = cancelButton;
}

- (void)updatePagesLabel
{
	self.pagesLabel.text = [NSString stringWithFormat:NSLocalizedString(@"Page of", nil), @(self.imageIndex).intValue, @(self.imagesCount).intValue];
}

- (void)didPressCancel:(id)sender
{
	if([self.delegate respondsToSelector:@selector(previewControllerDidCancel:)]) {
		[self.delegate previewControllerDidCancel:self];
	}
}

- (IBAction)didPressAddButton:(UIButton*)sender
{
	if([self.delegate respondsToSelector:@selector(previewController:didAddImage:)]) {
		[self.delegate previewController:self didAddImage:self.image];
	}
}

- (IBAction)didPressCloseButton:(UIButton*)sender
{
	if([self.delegate respondsToSelector:@selector(previewController:didCompleteWithImage:)]) {
		[self.delegate previewController:self didCompleteWithImage:self.image];
	}
}

@end
